@@ -20,6 +20,7 @@ from unify.properties import Properties
 from unify.properties import ClusterSetting
 
 cluster_name = "qa"
+
 props = Properties(clusterSetting=ClusterSetting.MEMORY)
 
 props.store_cluster(
@@ -30,10 +31,7 @@ props.store_cluster(
 )
 
 org_admin = OrgAdmin(props=props, cluster=cluster_name)
-props.set_auth_token(
-    token=org_admin.auth_token(),
-    cluster=cluster_name
-)
+
 test_org = org_admin.create_organization(
     org_name="zQA-{}".format(str(uuid.uuid4()))
 )
