@@ -41,10 +41,6 @@ class TestOrgAdmin(unittest.TestCase):
                 cluster=os.environ.get("cluster")
             )
             with OrgAdmin(props=props, cluster=cluster_name) as org_admin:
-                props.set_auth_token(
-                    token=org_admin.auth_token(),
-                    cluster=cluster_name
-                )
 
                 token = props.get_auth_token(cluster=cluster_name)
 
@@ -68,10 +64,6 @@ class TestOrgAdmin(unittest.TestCase):
             )
 
             with OrgAdmin(props=props, cluster=cluster_name) as org_admin:
-                props.set_auth_token(
-                    token=org_admin.auth_token(),
-                    cluster=cluster_name
-                )
 
                 org_id = org_admin.create_organization(
                     org_name="sdk-tests-{}".format(str(uuid.uuid4()))
