@@ -16,7 +16,6 @@
 Contains methods to interact with pipeline api
 """
 import json
-import time
 import uuid
 
 from tempfile import mkstemp
@@ -44,23 +43,15 @@ class Pipelines(ApiRequestManager):
 
         super().__init__(cluster=cluster, props=props)
 
-        self.epoch_time = int(time.time())
-        self.pi_tag_export_limit = {"piTagExportLimit": 999}
-        self.expiry = {"expiry": 999}
-
         try:
 
-            self.list_templates_uri = 'api/assetTemplates'
-            self.upload_content_type_header = {"Content-Type": "multipart/form-data"}
-            self.delete_content_type_header = {"Content-Type": "application/json"}
-
-            self.epoch_time = int(time.time())
-
             remote = self.props.get_remote(self.cluster)
 
             self.pipelines_url = self.props.get_remote(
                 self.cluster) + "tags/org/" + '{}' + "/pipelines"
 
+            self.regular_duplicate_url = self.pipelines_url + "/v2/{}/duplicate"
+
             self.delete_pipeline_url = self.pipelines_url + '/{}'
 
             self.pipeline_url = self.pipelines_url + '/{}'
@@ -120,7 +111,6 @@ class Pipelines(ApiRequestManager):
         final_url = self.apply_map_attributes_url.format(org_id, pipeline_id, component)
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.delete_content_type_header
         )
@@ -132,6 +122,38 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
+    def regular_duplicate(self, org_id, pipeline_id, new_name):
+        """
+        Will duplicate the given pipeline on the given org
+        :param org_id:
+        :param pipeline_id:
+        :param new_name:
+        :return:
+        """
+        headers = self.build_header(
+            org_id=org_id,
+            others={"Content-Type": "application/json"}
+        )
+
+        upload_url = self.regular_duplicate_url.format(org_id, pipeline_id)
+
+        post_upload_file = self.session.post(
+            upload_url,
+            headers=headers,
+            data=json.dumps({"name": new_name})
+        )
+
+        if post_upload_file.status_code == 200:
+            response = json.loads(post_upload_file.content)
+
+            if "sourceMetadata" in response:
+                del response["sourceMetadata"]
+
+            return response
+
+        raise Exception(repr(post_upload_file.content))
+
+
     def update_pipeline_from_json(self, org_id, update_payload, pipeline_id, pipeline_name, sources=None):
         """
         Updates a pipeline with a json content
@@ -149,8 +171,9 @@ class Pipelines(ApiRequestManager):
         :return:
         """
 
-        header = self.build_header(aut_token=self.props.get_auth_token(cluster=self.cluster),
-                                   org_id=org_id, others=self.content_type_header)
+        header = self.build_header(
+            org_id=org_id, others=self.content_type_header
+        )
 
         update_payload["name"] = str(pipeline_name)
 
@@ -215,7 +238,6 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -274,7 +296,6 @@ class Pipelines(ApiRequestManager):
         """
 
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others={"'Content-Type'": "application/data"}
         )
@@ -311,7 +332,6 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -346,7 +366,6 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -374,7 +393,6 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -401,7 +419,6 @@ class Pipelines(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -440,7 +457,6 @@ class Pipelines(ApiRequestManager):
             cols.append(('col', col_name))
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -463,7 +479,6 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
