@@ -390,6 +390,7 @@ class Sources(ApiRequestManager):
         )
 
         results["data_set_id"] = initial_commit["id"]
+        results["commit_id"] = initial_commit["commitId"]
 
         second_commit = self.append_command(
             org_id=org_id,
@@ -599,7 +600,17 @@ class Sources(ApiRequestManager):
         )
 
         if request.status_code in [200, 202]:
-            return json.loads(request.content)
+            append = json.loads(request.content)
+
+            Wait(200).until(
+                self.is_commit_completed,
+                "commit {} never completed".format(data_set_id),
+                org_id,
+                data_set_id,
+                append["commit_id"]
+            )
+
+            return append
         else:
             raise Exception(repr(request.content))
 
@@ -879,7 +890,16 @@ class Sources(ApiRequestManager):
         )
 
         if schema_request.status_code == 200:
-            return json.loads(schema_request.content)
+            results = json.loads(schema_request.content)
+
+            Wait(200).until(
+                self.is_commit_completed,
+                "commit {} never completed".format(results["id"]),
+                org_id,
+                results["id"],
+                results["commitId"]
+            )
+            return results
 
         raise Exception(repr(schema_request.content))
 
